==> knative-model-6.6.0-sources.jar: io/fabric8/knative/serving/v1/ConfigurationSpecFluentImpl.java <==
package io.fabric8.knative.serving.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConfigurationSpecFluentImpl<A extends ConfigurationSpecFluent<A>> extends BaseFluent<A> implements ConfigurationSpecFluent<A>{
  public ConfigurationSpecFluentImpl() {
  }
  public ConfigurationSpecFluentImpl(ConfigurationSpec instance) {
    this.withTemplate(instance.getTemplate()); 
  }
  private RevisionTemplateSpecBuilder template;
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public RevisionTemplateSpec getTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public RevisionTemplateSpec buildTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public A withTemplate(RevisionTemplateSpec template) {
    _visitables.get("template").remove(this.template);
    if (template!=null){ this.template= new RevisionTemplateSpecBuilder(template); _visitables.get("template").add(this.template);} else { this.template = null; _visitables.get("template").remove(this.template); } return (A) this;
  }
  public Boolean hasTemplate() {
    return this.template != null;
  }
  public ConfigurationSpecFluent.TemplateNested<A> withNewTemplate() {
    return new ConfigurationSpecFluentImpl.TemplateNestedImpl();
  }
  public ConfigurationSpecFluent.TemplateNested<A> withNewTemplateLike(RevisionTemplateSpec item) {
    return new ConfigurationSpecFluentImpl.TemplateNestedImpl(item);
  }
  public ConfigurationSpecFluent.TemplateNested<A> editTemplate() {
    return withNewTemplateLike(getTemplate());
  }
  public ConfigurationSpecFluent.TemplateNested<A> editOrNewTemplate() {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): new RevisionTemplateSpecBuilder().build());
  }
  public ConfigurationSpecFluent.TemplateNested<A> editOrNewTemplateLike(RevisionTemplateSpec item) {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConfigurationSpecFluentImpl that = (ConfigurationSpecFluentImpl) o;
    if (template != null ? !template.equals(that.template) :that.template != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(template,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (template != null) { sb.append("template:"); sb.append(template); }
    sb.append("}");
    return sb.toString();
  }
  class TemplateNestedImpl<N> extends RevisionTemplateSpecFluentImpl<ConfigurationSpecFluent.TemplateNested<N>> implements ConfigurationSpecFluent.TemplateNested<N>,Nested<N>{
    TemplateNestedImpl(RevisionTemplateSpec item) {
      this.builder = new RevisionTemplateSpecBuilder(this, item);
    }
    TemplateNestedImpl() {
      this.builder = new RevisionTemplateSpecBuilder(this);
    }
    RevisionTemplateSpecBuilder builder;
    public N and() {
      return (N) ConfigurationSpecFluentImpl.this.withTemplate(builder.build());
    }
    public N endTemplate() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/serving/v1/ConfigurationSpecFluentImpl.java <==
package io.fabric8.knative.serving.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ConfigurationSpecFluentImpl<A extends ConfigurationSpecFluent<A>> extends BaseFluent<A> implements ConfigurationSpecFluent<A>{
  public ConfigurationSpecFluentImpl() {
  }
  public ConfigurationSpecFluentImpl(ConfigurationSpec instance) {
    if (instance != null) {
      this.withTemplate(instance.getTemplate());
    }
  }
  private RevisionTemplateSpecBuilder template;
  
  /**
   * This method has been deprecated, please use method buildTemplate instead.
   * @return The buildable object.
   */
  @Deprecated
  public RevisionTemplateSpec getTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public RevisionTemplateSpec buildTemplate() {
    return this.template!=null ?this.template.build():null;
  }
  public A withTemplate(RevisionTemplateSpec template) {
    _visitables.get("template").remove(this.template);
    if (template!=null){ this.template= new RevisionTemplateSpecBuilder(template); _visitables.get("template").add(this.template);} else { this.template = null; _visitables.get("template").remove(this.template); } return (A) this;
  }
  public Boolean hasTemplate() {
    return this.template != null;
  }
  public ConfigurationSpecFluentImpl.TemplateNested<A> withNewTemplate() {
    return new ConfigurationSpecFluentImpl.TemplateNestedImpl();
  }
  public ConfigurationSpecFluentImpl.TemplateNested<A> withNewTemplateLike(RevisionTemplateSpec item) {
    return new ConfigurationSpecFluentImpl.TemplateNestedImpl(item);
  }
  public ConfigurationSpecFluentImpl.TemplateNested<A> editTemplate() {
    return withNewTemplateLike(getTemplate());
  }
  public ConfigurationSpecFluentImpl.TemplateNested<A> editOrNewTemplate() {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): new RevisionTemplateSpecBuilder().build());
  }
  public ConfigurationSpecFluentImpl.TemplateNested<A> editOrNewTemplateLike(RevisionTemplateSpec item) {
    return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ConfigurationSpecFluentImpl that = (ConfigurationSpecFluentImpl) o;
    if (!java.util.Objects.equals(template, that.template)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(template,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (template != null) { sb.append("template:"); sb.append(template); }
    sb.append("}");
    return sb.toString();
  }
  class TemplateNestedImpl<N> extends RevisionTemplateSpecFluentImpl<ConfigurationSpecFluentImpl.TemplateNested<N>> implements ConfigurationSpecFluentImpl.TemplateNested<N>,Nested<N>{
    TemplateNestedImpl(RevisionTemplateSpec item) {
      this.builder = new RevisionTemplateSpecBuilder(this, item);
    }
    TemplateNestedImpl() {
      this.builder = new RevisionTemplateSpecBuilder(this);
    }
    RevisionTemplateSpecBuilder builder;
    public N and() {
      return (N) ConfigurationSpecFluentImpl.this.withTemplate(builder.build());
    }
    public N endTemplate() {
      return and();
    }
    
  }
  
}
